@@ -5,9 +5,9 @@
 #
 
 import textwrap
+from unittest.mock import Mock
 
 import pytest
-from mock import Mock
 
 from comitup import routemgr
 
